@@ -1,6 +1,6 @@
-import logging
 from collections import Counter
 from math import floor
+from t2wml.utils.debug_logging import basic_debug
 from t2wml.input_processing.utils import string_is_valid
 from t2wml.wikification.country_wikifier_cache import countries
 from t2wml.utils.date_utils import parse_datetime
@@ -20,9 +20,8 @@ def get_types(cell_content):
         is_date=False
     return is_country, is_numeric, is_date
 
-
+@basic_debug
 def annotation_suggester(sheet, selection, annotation_blocks_array):
-    logging.debug("enter annotation suggester")
     already_has_subject=False
     already_has_var=False
     for block in annotation_blocks_array:
@@ -67,14 +66,13 @@ def annotation_suggester(sheet, selection, annotation_blocks_array):
     suggestion=dict(role=role, children=children)
     if type:
         suggestion["type"]=type
-    logging.debug("return from annotation suggester")
     return suggestion
 
 
 class HistogramSelection:
     @staticmethod
+    @basic_debug
     def block_finder(sheet):
-        logging.debug("enter HistrogramSelection.blockfinder")
         vertical_numbers=Counter()
         horizontal_numbers=Counter()
         horizontal_dates=Counter()
@@ -88,7 +86,7 @@ class HistogramSelection:
 
         for row in range(sheet.row_len):
             for col in range(sheet.col_len):
-                content = sheet[row][col]
+                content = sheet[row, col]
                 if not string_is_valid(content):
                     blanks.add((row, col))
                     continue
@@ -126,7 +124,6 @@ class HistogramSelection:
         
         date_block=HistogramSelection.normalize_to_selection(date_block, number_block)
         country_block=HistogramSelection.normalize_to_selection(country_block, number_block)
-        logging.debug("return from HistrogramSelection.blockfinder")
         return HistogramSelection._create_annotations(date_block, country_block, number_block)
         
     def normalize_to_selection(selection, normalize_against):
