@@ -1,4 +1,4 @@
-import logging
+from t2wml.utils.debug_logging import basic_debug
 import yaml
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.parsing.t2wml_parsing import T2WMLCode
@@ -10,8 +10,8 @@ class ForwardSlashEscape(Exception):  # used for a little hack down below
 
 
 class CodeParser:
+    @basic_debug
     def fix_code_string(self, e_str):
-        logging.debug("enter CodeParser.fix_code_string")
         # we made various compromises between valid code from the get-go and easy for the user code.
         # this function transforms user code into python-acceptable code
         e_str = str(e_str)
@@ -23,7 +23,6 @@ class CodeParser:
         e_str = e_str.replace("$", "t_var_")
         # "condition and result" is equivalent to "if condition, result"
         e_str = e_str.replace("->", " and ")
-        logging.debug("return from CodeParser.fix_code_string")
         return e_str[1:]  # get rid of starting equal sign
 
     def is_code_string(self, statement):
@@ -54,24 +53,20 @@ class TemplateParser(CodeParser):
         self.template = template
         self.eval_template = self.create_eval_template(self.template)
 
+    @basic_debug
     def get_code_replacement(self, input_str):
-        logging.debug("enter TemplateParser.get_code_replacement")
         try:
             if self.is_code_string(input_str):
                 try:
                     fixed = self.fix_code_string(input_str)
                     compiled_statement = compile(fixed, "<string>", "eval")
-                    logging.debug("return from TemplateParser.get_code_replacement")
                     return T2WMLCode(compiled_statement, fixed, input_str)
                 except Exception as e:
-                    logging.debug("raise from TemplateParser.get_code_replacement")
                     raise T2WMLExceptions.ErrorInYAMLFileException(
                         "Invalid expression: "+str(input_str))
             else:
-                logging.debug("return from TemplateParser.get_code_replacement")
                 return input_str
         except ForwardSlashEscape as e:
-            logging.debug("return from TemplateParser.get_code_replacement")
             return e.new_str
     
     def recursive_get_code_replacement(self, input):
@@ -98,17 +93,15 @@ class Template:
         self.eval_template = eval_template
 
     @staticmethod
+    @basic_debug
     def create_from_yaml(yaml_data):
-        logging.debug("enter Template.create_from_yaml")
         template = dict(yaml_data)
         template_parser = TemplateParser(template)
         eval_template = template_parser.eval_template
-        logging.debug("return from Template.create_from_yaml")
         return Template(template, eval_template)
 
-
+@basic_debug
 def validate_yaml(yaml_file_path):
-    logging.debug("enter validate yaml")
     with open(yaml_file_path, 'r', encoding="utf-8") as stream:
         try:
             yaml_file_data = yaml.safe_load(stream)
@@ -220,5 +213,4 @@ def validate_yaml(yaml_file_path):
 
     if errors:
         raise T2WMLExceptions.ErrorInYAMLFileException(errors)
-    logging.debug("return from validate yaml")
     return yaml_file_data
