@@ -1,6 +1,7 @@
 import logging
 from abc import ABC, abstractmethod
 import json
+from t2wml.utils.debug_logging import basic_debug
 import yaml
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.mapping.statements import EvaluatedStatement, PartialStatement, StatementError
@@ -26,8 +27,8 @@ class StatementMapper(ABC):
     def do_init(self, sheet, wikifier):
         pass
 
+    @basic_debug
     def get_statements(self, sheet, wikifier, start=0, end=None):
-        logging.debug("enter get_statements")
         self.do_init(sheet, wikifier)
         statements = {}
         cell_errors = {}
@@ -44,7 +45,7 @@ class StatementMapper(ABC):
             if i<start:
                 continue
             errors=[]
-            if string_is_valid(str(bindings.excel_sheet[row-1][col-1])):
+            if string_is_valid(str(bindings.excel_sheet[row-1, col-1])):
                 cell = to_excel(col-1, row-1)
                 try:
                     statement, inner_errors = self.get_cell_statement(
@@ -63,7 +64,6 @@ class StatementMapper(ABC):
                     cell_errors[cell] = [error.__dict__ if isinstance(error, StatementError) else error for error in errors ]
             if i == end:
                 break
-        logging.debug("returning from get_statements")
         return statements, cell_errors, metadata
 
 
@@ -74,23 +74,20 @@ class YamlMapper(StatementMapper):
         self.file_path = file_path
         self.yaml_data = validate_yaml(file_path)
 
+    @basic_debug
     def do_init(self, sheet, wikifier):
-        logging.debug("enter YamlMapper do_init")
         if self.yaml_data.get("cleaningMapping"):
             new_df=get_cleaned_dataframe(sheet, self.yaml_data["cleaningMapping"])
             sheet.cleaned_data=new_df
         update_bindings(item_table=wikifier.item_table, sheet=sheet)
-        logging.debug("exiting YamlMapper do_init")
         
-
+    @basic_debug
     def get_cell_statement(self, sheet, wikifier, col, row, do_init=True):
-        logging.debug("enter YamlMapper get_cell_statement")
         if do_init:
             self.do_init(sheet, wikifier)
         context = {"t_var_row": row, "t_var_col": col}
         statement = EvaluatedStatement(
             context=context, **self.template.eval_template)
-        logging.debug("returning from YamlMapper get_cell_statement")
         return statement.serialize(), statement.errors
 
     def iterator(self):
@@ -100,14 +97,11 @@ class YamlMapper(StatementMapper):
 
     @property
     def template(self):
-        logging.debug("enter template property in YamlMapper")
         try:
-            logging.debug("returning from template property in YamlMapper")
             return self._template
         except:
             self._template = Template.create_from_yaml(
                 self.yaml_data['statementMapping']['template'])
-            logging.debug("returning from template property in YamlMapper")
             return self._template
 
 class AnnotationMapper(YamlMapper):
@@ -117,34 +111,28 @@ class AnnotationMapper(YamlMapper):
         self.init_annotation(file_path)
         if not self.annotation.potentially_enough_annotation_information:
             self.get_statements=self.empty_get_statements #override get_statements to not return anything
-    
+    @basic_debug
     def init_annotation(self, file_path):
-        logging.debug("enter AnnotationMapper init_annotation")
         self.file_path = file_path
         with open(file_path, 'r') as f:
             annotation_blocks_arr=json.load(f)
         self.annotation=Annotation(annotation_blocks_arr)
-        logging.debug("exit AnnotationMapper init_annotation")
-
 
+    @basic_debug
     def do_init(self, sheet, wikifier):
-        logging.debug("enter AnnotationMapper do_init")
         item_table=wikifier.item_table
         update_bindings(item_table=item_table, sheet=sheet)
         yamlContent=self.annotation.generate_yaml(sheet=sheet, item_table=item_table)[0]
         self.yaml_data = yaml.safe_load(yamlContent)
-        logging.debug("exit AnnotationMapper do_init")
 
-    
+    @basic_debug
     def empty_get_statements(self, sheet, wikifier, *args, **kwargs):
-        logging.debug("enter empty_get_statements")
         statements = {}
         cell_errors = []
         metadata = {
             "data_file": sheet.data_file_name,
             "sheet_name": sheet.name,
         }
-        logging.debug("return from empty_get_statements")
         return statements, cell_errors, metadata
 
 class PartialAnnotationMapper(AnnotationMapper):
@@ -152,9 +140,8 @@ class PartialAnnotationMapper(AnnotationMapper):
         self.init_annotation(file_path)
         if not self.annotation.data_annotations:
             self.get_statements=self.empty_get_statements
-
+    @basic_debug
     def get_cell_statement(self, sheet, wikifier, col, row, do_init=True):
-        logging.debug("enter PArtialAnnotationMapper get cell statement")
         if do_init:
             self.do_init(sheet, wikifier)
         context = {"t_var_row": row, "t_var_col": col}
@@ -162,7 +149,6 @@ class PartialAnnotationMapper(AnnotationMapper):
         serialized_statement=statement.serialize()
         if "value" not in serialized_statement: #circumvent the check against empty values
             serialized_statement["value"]=""
-        logging.debug("returning from PArtialAnnotationMapper get cell statement")
         return serialized_statement, statement.errors
     
 
