@@ -1,4 +1,5 @@
 import json
+from t2wml.utils.debug_logging import basic_debug, with_args_debug
 import pandas as pd
 import logging
 from pandas import DataFrame
@@ -10,9 +11,17 @@ from t2wml.utils.bindings import bindings
 class ItemTable:
     def __init__(self, lookup_table={}):
         self.lookup_table = defaultdict(dict, lookup_table)
+    
+    def __repr__(self):
+        return "<Item Table>"
+
+    @with_args_debug
+    def lookup_func(self, context, file, sheet, column, row, value):
+        lookup = self.lookup_table.get(context)
+        if not lookup:
+            raise ItemNotFoundException(
+                "Search for cell item failed. (No values defined for context: {})".format(context))
 
-    def lookup_func(self, lookup, file, sheet, column, row, value):
-        logging.debug("enter ItemTable.lookup_func")
         # order of priority: cell+value> cell> col+value> col> row+value> row> value
         column = int(column)
         row = int(row)
@@ -30,23 +39,18 @@ class ItemTable:
         for tup in tuples:
             item = lookup.get(str(tup))
             if item:
-                logging.debug("returning from ItemTable.lookup_func")
                 return item
-        logging.debug("raising not found from ItemTable.lookup_func")
         raise ValueError("Not found")
 
-    def get_item(self, column:int, row:int, context:str='', sheet=None):
-        lookup = self.lookup_table.get(context)
-        if not lookup:
-            raise ItemNotFoundException(
-                "Search for cell item failed. (No values defined for context: {})".format(context))
+    def get_item(self, column:int, row:int, context:str='', sheet=None, value=None):
         if not sheet:
             sheet = bindings.excel_sheet
         file=sheet.data_file_name
         sheet_name=sheet.name
-        value = str(sheet[row, column])
+        if value is None:
+            value = str(sheet[row, column])
         try:
-            item = self.lookup_func(lookup, file, sheet_name, column, row, value)
+            item = self.lookup_func(context, file, sheet_name, column, row, value)
             return item
         except ValueError:
             return None  # currently this is what the rest of the API expects. could change later
@@ -67,13 +71,14 @@ class ItemTable:
         # used to serialize table
         bindings.excel_sheet = sheet
         for context in self.lookup_table:
-            item = self.get_item(column, row, context, sheet=sheet)
+            value= bindings.excel_sheet[row, column]
+            item = self.get_item(column, row, context, sheet=sheet, value=value)
             if item:
-                return item, context, bindings.excel_sheet[row, column]
+                return item, context, value
         return None, None, None
 
+    @with_args_debug
     def update_table_from_dataframe(self, df: DataFrame):
-        logging.debug("enter ItemTable update table from dataframe")
         try:
             df = df.fillna('')
             df = df.replace(r'^\s+$', '', regex=True)
@@ -112,8 +117,6 @@ class ItemTable:
         except Exception as e:
             print(e)
             raise e
-        finally:
-            logging.debug("finished ItemTable update table from dataframe")
 
 
 class Wikifier:
@@ -136,6 +139,7 @@ class Wikifier:
     def item_table(self):
         return self._item_table
 
+    @with_args_debug
     def add_file(self, file_path: str):
         """add a wikifier file to the wikifier. loads the file and adds it to the item table.
         file must be a csv file, and must contain the columns 'row', 'column', 'value', 'context', 'item'
@@ -150,7 +154,6 @@ class Wikifier:
         Returns:
             dict: a dictionary describing which item definitions were already present and overwritten
         """
-        logging.debug("enter Wikifier add_file")
         df = pd.read_csv(file_path)
         try:
             overwritten = self.item_table.update_table_from_dataframe(df)
@@ -159,9 +162,9 @@ class Wikifier:
                 "Could not apply {} : {}".format(file_path, str(e)))
         self.wiki_files.append(file_path)
         self._data_frames.append(df)
-        logging.debug("returning from Wikifier add_file")
         return overwritten
 
+    @with_args_debug
     def add_dataframe(self, df: DataFrame):
         """Add a wikifier dataframe to the Wikifier item table
 
@@ -176,7 +179,6 @@ class Wikifier:
         Returns:
             dict: a dictionary describing which item definitions were already present and overwritten
         """
-        logging.debug("entering Wikifier add_dataframe")
         expected_columns = set(['row', 'column', 'value', 'context', 'item'])
         columns = set(df.columns)
         missing_columns = expected_columns.difference(columns)
@@ -188,16 +190,15 @@ class Wikifier:
         except Exception as e:
             raise ValueError("Could not apply dataframe: "+str(e))
         self._data_frames.append(df)
-        logging.debug("returning from Wikifier add_dataframe")
         return overwritten
 
+    @basic_debug
     def save(self, filename: str):
         """save Wikifier to a json file
 
         Args:
             filename (str): location of save file
         """
-        logging.debug("enter wikifier save"+ filename)
         output = json.dumps({
             "wiki_files": self.wiki_files,
             "lookup_table": self.item_table.lookup_table,
@@ -205,9 +206,9 @@ class Wikifier:
         })
         with open(filename, 'w', encoding="utf-8") as f:
             f.write(output)
-        logging.debug("exit Wikifier save", filename)
 
     @classmethod
+    @basic_debug
     def load(cls, filename:str):
         """load Wikifier from saved json file (created by the wikifier save method)
 
@@ -217,7 +218,6 @@ class Wikifier:
         Returns:
             Wikifier: initialized wikifier
         """
-        logging.debug("enter wikifier load"+ filename)
         with open(filename, 'r', encoding="utf-8") as f:
             wiki_args = json.load(f)
         wikifier = Wikifier()
@@ -226,5 +226,4 @@ class Wikifier:
             lookup_table=wiki_args["lookup_table"])
         wikifier._data_frames = [pd.read_json(
             json_string) for json_string in wiki_args["dataframes"]]
-        logging.debug("return from wikifier load"+ filename)
         return wikifier
