@@ -1,7 +1,7 @@
 from collections import defaultdict
-import logging
 import csv
 from pathlib import Path
+from t2wml.utils.debug_logging import basic_debug
 from t2wml.utils.date_utils import VALID_PROPERTY_TYPES
 from SPARQLWrapper.SPARQLExceptions import QueryBadFormed
 from t2wml.utils import t2wml_exceptions as T2WMLExceptions
@@ -14,40 +14,32 @@ def get_default_provider():
     wikidata_provider = DictionaryProvider(preloaded_properties)
     return wikidata_provider
 
+@basic_debug
 def get_provider():
-    logging.debug("enter get_provider")
     wikidata_provider = t2wml_settings.wikidata_provider
     if wikidata_provider is None:
         wikidata_provider = get_default_provider()
         t2wml_settings.wikidata_provider = wikidata_provider
-    logging.debug("returning from get_provider")
     return wikidata_provider
 
-
+@basic_debug
 def get_property_type(prop):
-    logging.debug("enter get_property_type")
     try:
         prop_type = _get_property_type(prop)
-        logging.debug("returning from get_property_type")
         return str(prop_type).lower()
     except QueryBadFormed:
-        logging.debug("raising QueryBadFormed error from get_property_type")
         raise T2WMLExceptions.UnsupportedPropertyType(
             "The value given for property is not a valid property:" + str(prop))
     except ValueError:
-        logging.debug("raising ValueError from get_property_type")
         raise T2WMLExceptions.UnsupportedPropertyType(
             "Property not found:" + str(prop))
 
-
+@basic_debug
 def _get_property_type(wikidata_property):
-    logging.debug("enter _get_property_type")
     provider = get_provider()
     property_type = provider.get_property_type(wikidata_property)
     if property_type == "Property Not Found":
-        logging.debug("raising unsupported property type error from _get_property_type")
         raise T2WMLExceptions.UnsupportedPropertyType("Property "+wikidata_property+" not found")
-    logging.debug("returning from _get_property_type")
     return property_type
 
 
@@ -64,10 +56,9 @@ def validate_id(node_id):
     except ValueError: #conversion to int failed, is not Pnum or Qnum
         pass
 
-
+@basic_debug
 def kgtk_to_dict(file_path):
     #if label is P2010050001 (datamart tag), the key is tags and a list is generated
-    logging.debug("entering kgtk_to_dict")
     input_dict=defaultdict(dict)
     with open(file_path, 'r', encoding="utf-8") as f:
         reader = csv.DictReader(f, delimiter="\t")
@@ -82,11 +73,10 @@ def kgtk_to_dict(file_path):
                     input_dict[node1]["tags"]=[value]
             else:
                 input_dict[node1][label]=value
-    logging.debug("returning from kgtk_to_dict")
     return dict(input_dict)
 
+@basic_debug
 def dict_to_kgtk(in_dict, out_path):
-    logging.debug("entering dict_to_kgtk")
     tsv_dict_columns=["id", "node1", "label", "node2"]
     tsv_dict_arr=[]
     for node1, node_dict in in_dict.items():
@@ -104,10 +94,9 @@ def dict_to_kgtk(in_dict, out_path):
         dw.writeheader()
         for line in tsv_dict_arr:
             dw.writerow(line)
-    logging.debug("exiting dict_to_kgtk")
-
 
 
+@basic_debug
 def add_entities_from_file(file_path: str, validate_ids=True):
     """load wikidata entries from a file and add them to the current WikidataProvider as defined in settings.
     If a kgtk-format tsv file, the property information will be loaded as follows:
@@ -130,7 +119,6 @@ def add_entities_from_file(file_path: str, validate_ids=True):
     Returns:
         dict: a dictionary of "added", "present" (already present, updated), and "failed" properties from the file
     """
-    logging.debug("entering add_entities_from_file")
     if Path(file_path).suffix != ".tsv":
         raise T2WMLExceptions.UnsupportedPropertyType(
             "Only .tsv property files are currently supported")
@@ -171,5 +159,4 @@ def add_entities_from_file(file_path: str, validate_ids=True):
             except Exception as e:
                 print(e)
                 return_dict["failed"].append((node_id, str(e)))
-    logging.debug("returning from add_entities_from_file")
     return return_dict
\ No newline at end of file
