@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 import logging
+from t2wml.utils.debug_logging import basic_debug
 from SPARQLWrapper import SPARQLWrapper, JSON
 from t2wml.settings import t2wml_settings
 
@@ -44,8 +45,8 @@ class SparqlProvider(WikidataProvider):
         self.sparql_endpoint = sparql_endpoint
         self.cache = {}
 
+    @basic_debug
     def query_wikidata_for_property_type(self, wikidata_property):
-        logging.debug("enter SparlProvider query wikidata for property type")
         query = """SELECT ?label ?desc ?type
                 WHERE 
                 {{
@@ -70,7 +71,6 @@ class SparqlProvider(WikidataProvider):
         except IndexError:
             data_type = "Property Not Found"
             label=description=""
-        logging.debug("returning from SparlProvider query wikidata for property type")
         return dict(data_type=data_type, label=label, description=description)
 
     def get_property_type(self, wikidata_property: str):
@@ -104,15 +104,13 @@ class FallbackSparql(SparqlProvider):
     falling back to sparql queries (and then optionally saving query response to the main source)
     '''
 
+    @basic_debug
     def get_property_type(self, wikidata_property, *args, **kwargs):
         
         try:
-            logging.debug("entering FallBackSparql try_get_property_type")
             data_type = self.try_get_property_type(
                 wikidata_property, *args, **kwargs)
-            logging.debug("FallBackSparql try_get_property_type returned successfully")
         except Exception as e:
-            logging.debug(f"FallBackSparql try_get_property_type failed because {str(e)}, falling back to sparql query")
             data_type = super().get_property_type(wikidata_property)
         return data_type
 
@@ -121,11 +119,10 @@ class FallbackSparql(SparqlProvider):
 
 
 class DictionaryProvider(SparqlProvider):
+    @basic_debug
     def __init__(self, ref_dict, sparql_endpoint=None, *args, **kwargs):
-        logging.debug("initializing dictionary provider")
         super().__init__(sparql_endpoint)
         self.cache = ref_dict
-        logging.debug("finished initializing dictionary provider")
     
 class KGTKFileProvider():
     def __init__(self, file_path):
